summaryrefslogtreecommitdiff
path: root/source3/auth/auth_server.c
diff options
context:
space:
mode:
authorTim Potter <tpot@samba.org>2001-11-26 04:05:28 +0000
committerTim Potter <tpot@samba.org>2001-11-26 04:05:28 +0000
commit178f6a64b26d828db6b516392d7072e9c29f6233 (patch)
treedc7f83d479cf9994e8c751f4bd475174071cac38 /source3/auth/auth_server.c
parentabe6aff924ed56a36ba6390d692446019bef0f21 (diff)
downloadsamba-178f6a64b26d828db6b516392d7072e9c29f6233.tar.gz
samba-178f6a64b26d828db6b516392d7072e9c29f6233.tar.bz2
samba-178f6a64b26d828db6b516392d7072e9c29f6233.zip
challange -> challenge
(This used to be commit d6318add27f6bca5be00cbedf2226b642341297a)
Diffstat (limited to 'source3/auth/auth_server.c')
-rw-r--r--source3/auth/auth_server.c16
1 files changed, 8 insertions, 8 deletions
diff --git a/source3/auth/auth_server.c b/source3/auth/auth_server.c
index 067b5b2997..a3cfc3a0e6 100644
--- a/source3/auth/auth_server.c
+++ b/source3/auth/auth_server.c
@@ -135,10 +135,10 @@ static void send_server_keepalive(void **private_data_pointer)
}
/****************************************************************************
- Get the challange out of a password server.
+ Get the challenge out of a password server.
****************************************************************************/
-static DATA_BLOB auth_get_challange_server(void **my_private_data, const struct authsupplied_info *auth_info)
+static DATA_BLOB auth_get_challenge_server(void **my_private_data, const struct authsupplied_info *auth_info)
{
struct cli_state *cli = server_cryptkey();
@@ -147,14 +147,14 @@ static DATA_BLOB auth_get_challange_server(void **my_private_data, const struct
if ((cli->sec_mode & 2) == 0) {
/* We can't work with unencrypted password servers
unless 'encrypt passwords = no' */
- DEBUG(5,("make_auth_info_server: Server is unencrypted, no challange available..\n"));
+ DEBUG(5,("make_auth_info_server: Server is unencrypted, no challenge available..\n"));
*my_private_data = (void *)cli;
return data_blob(NULL, 0);
} else if (cli->secblob.length < 8) {
- /* We can't do much if we don't get a full challange */
- DEBUG(2,("make_auth_info_server: Didn't receive a full challange from server\n"));
+ /* We can't do much if we don't get a full challenge */
+ DEBUG(2,("make_auth_info_server: Didn't receive a full challenge from server\n"));
cli_shutdown(cli);
return data_blob(NULL, 0);
}
@@ -205,8 +205,8 @@ static NTSTATUS check_smbserver_security(void *my_private_data,
return NT_STATUS_LOGON_FAILURE;
}
} else {
- if (memcmp(cli->secblob.data, auth_info->challange.data, 8) != 0) {
- DEBUG(1,("the challange that the password server (%s) supplied us is not the one we gave our client. This just can't work :-(\n", cli->desthost));
+ if (memcmp(cli->secblob.data, auth_info->challenge.data, 8) != 0) {
+ DEBUG(1,("the challenge that the password server (%s) supplied us is not the one we gave our client. This just can't work :-(\n", cli->desthost));
return NT_STATUS_LOGON_FAILURE;
}
}
@@ -347,7 +347,7 @@ BOOL auth_init_smbserver(auth_methods **auth_method)
return False;
}
(*auth_method)->auth = check_smbserver_security;
- (*auth_method)->get_chal = auth_get_challange_server;
+ (*auth_method)->get_chal = auth_get_challenge_server;
(*auth_method)->send_keepalive = send_server_keepalive;
(*auth_method)->free_private_data = free_server_private_data;
return True;